"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dataSourceConfig = exports.config = void 0;
const migrations_1 = require("./database/migrations");
const model_1 = require("./database/model");
const service_common_1 = require("@crosslab/service-common");
const process_1 = require("process");
function die(reason) {
    service_common_1.logger.log('error', reason);
    (0, process_1.exit)(1);
}
function initializeAppConfiguration() {
    return {
        PORT: parseInt(process.env.PORT ?? '3000'),
        NODE_ENV: process.env.NODE_ENV ?? 'development',
        BASE_URL: process.env.BASE_URL ?? 'http://localhost:3000',
        JWKS_URL: process.env.JWKS_URL ?? 'http://localhost/.well-known/jwks.json',
        SECURITY_ISSUER: process.env.SECURITY_ISSUER ??
            die('the environment variable SECURITY_ISSUER is not defined!'),
        SECURITY_AUDIENCE: process.env.SECURITY_AUDIENCE ??
            die('the environment variable SECURITY_AUDIENCE is not defined!'),
        API_TOKEN: process.env.API_TOKEN ??
            die('the environment variable API_TOKEN is not defined'),
    };
}
exports.config = initializeAppConfiguration();
exports.dataSourceConfig = {
    type: 'sqlite',
    database: 'db/experiment.db',
    entities: [
        model_1.ExperimentModel,
        model_1.DeviceModel,
        model_1.InstanceModel,
        model_1.ServiceConfigurationModel,
        model_1.PeerconnectionModel,
        model_1.ParticipantModel,
        model_1.RoleModel,
    ],
    migrations: [...migrations_1.Migrations],
    migrationsRun: true,
};
//# sourceMappingURL=config.js.map