"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dataSource = exports.repositories = exports.AppDataSource = void 0;
const config_1 = require("../config");
const device_1 = require("./repositories/device");
const experiment_1 = require("./repositories/experiment");
const instance_1 = require("./repositories/instance");
const participant_1 = require("./repositories/participant");
const peerconnection_1 = require("./repositories/peerconnection");
const role_1 = require("./repositories/role");
const serviceConfiguration_1 = require("./repositories/serviceConfiguration");
const service_common_1 = require("@crosslab/service-common");
class ApplicationDataSource extends service_common_1.AbstractApplicationDataSource {
    constructor(options) {
        super(options);
        this.repositories = this.createRepositories();
    }
    createRepositories() {
        const deviceRepository = new device_1.DeviceRepository();
        const experimentRepository = new experiment_1.ExperimentRepository();
        const instanceRepository = new instance_1.InstanceRepository();
        const participantRepository = new participant_1.ParticipantRepository();
        const peerconnectionRepository = new peerconnection_1.PeerconnectionRepository();
        const roleRepository = new role_1.RoleRepository();
        const serviceConfigurationRepository = new serviceConfiguration_1.ServiceConfigurationRepository();
        deviceRepository.setDependencies({
            instance: instanceRepository,
        });
        experimentRepository.setDependencies({
            device: deviceRepository,
            peerconnection: peerconnectionRepository,
            role: roleRepository,
            serviceConfiguration: serviceConfigurationRepository,
        });
        serviceConfigurationRepository.setDependencies({
            participant: participantRepository,
        });
        return {
            device: deviceRepository,
            experiment: experimentRepository,
            instance: instanceRepository,
            participant: participantRepository,
            peerconnection: peerconnectionRepository,
            role: roleRepository,
            serviceConfiguration: serviceConfigurationRepository,
        };
    }
}
exports.AppDataSource = new ApplicationDataSource(config_1.dataSourceConfig);
exports.repositories = exports.AppDataSource.repositories;
exports.dataSource = exports.AppDataSource.dataSource;
//# sourceMappingURL=dataSource.js.map