"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceConfigurationRepository = void 0;
const model_1 = require("../model");
const service_common_1 = require("@crosslab/service-common");
class ServiceConfigurationRepository extends service_common_1.AbstractRepository {
    constructor() {
        super('ServiceConfiguration');
        this.dependencies = {};
    }
    dependenciesMet() {
        return true;
    }
    initialize(entityManager) {
        this.repository = entityManager.getRepository(model_1.ServiceConfigurationModel);
    }
    async write(model, data) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        if (data.serviceType)
            model.serviceType = data.serviceType;
        if (data.configuration)
            model.configuration = data.configuration;
        if (data.participants) {
            for (const participant of model.participants ?? []) {
                await this.dependencies.participant.remove(participant);
            }
            model.participants = [];
            for (const participant of data.participants) {
                const participantModel = await this.dependencies.participant.create(participant);
                model.participants.push(participantModel);
            }
        }
    }
    async format(model) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        const participantRepository = this.dependencies.participant;
        return {
            serviceType: model.serviceType,
            configuration: model.configuration,
            participants: await Promise.all(model.participants?.map((participant) => participantRepository.format(participant)) ?? []),
        };
    }
    async remove(model) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        const participantRepository = this.dependencies.participant;
        const removePromises = [];
        if (model.participants)
            removePromises.push(...model.participants.map((participant) => participantRepository.remove(participant)));
        await Promise.all(removePromises);
        await super.remove(model);
    }
}
exports.ServiceConfigurationRepository = ServiceConfigurationRepository;
//# sourceMappingURL=serviceConfiguration.js.map