#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
const dataSource_1 = require("./database/dataSource");
const index_1 = require("./generated/index");
const types_1 = require("./generated/types");
const api_1 = require("./methods/api");
const callbacks_1 = require("./operations/callbacks");
const service_common_1 = require("@crosslab/service-common");
async function startExperimentService() {
    await dataSource_1.AppDataSource.initialize(config_1.dataSourceConfig);
    api_1.apiClient.accessToken = config_1.config.API_TOKEN;
    index_1.app.get('/experiment/status', (_req, res) => {
        res.send({ status: 'ok' });
    });
    index_1.app.initService({
        security: {
            JWT: (0, service_common_1.JWTVerify)(config_1.config, types_1.isUserTypeJWT, service_common_1.parseJwtFromAuthorizationHeader),
        },
        preHandlers: [service_common_1.requestIdHandling, service_common_1.logHandling],
        postHandlers: [callbacks_1.callbackHandling, service_common_1.missingRouteHandling],
        errorHandler: service_common_1.errorHandler,
    });
    index_1.app.listen(config_1.config.PORT);
    service_common_1.logger.log('info', 'Experiment Service started successfully');
}
/** istanbul ignore if */
if (require.main === module) {
    startExperimentService();
}
//# sourceMappingURL=index.js.map