"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.finishExperiment = void 0;
const assert_1 = __importDefault(require("assert"));
const dataSource_1 = require("../../database/dataSource");
const api_1 = require("../api");
const url_1 = require("../url");
const service_common_1 = require("@crosslab/service-common");
const typeguards_1 = require("../../types/typeguards");
/**
 * This function attempts to finish an experiment.
 * @param experimentModel The experiment to be finished.
 */
async function finishExperiment(experimentModel) {
    const experimentUrl = (0, url_1.experimentUrlFromId)(experimentModel.uuid);
    service_common_1.logger.log('info', 'Attempting to finish experiment', { data: { experimentUrl } });
    switch (experimentModel.status) {
        case 'created': {
            break;
        }
        case 'booked': {
            (0, assert_1.default)((0, typeguards_1.validateExperimentStatus)(experimentModel, 'booked'));
            // await apiClient.deleteBooking(experimentModel.bookingID)
            break;
        }
        case 'booking-locked': {
            (0, assert_1.default)((0, typeguards_1.validateExperimentStatus)(experimentModel, 'booking-locked'));
            // await apiClient.unlockBooking(experimentModel.bookingID)
            // await apiClient.deleteBooking(experimentModel.bookingID)
            break;
        }
        case 'devices-instantiated': {
            (0, assert_1.default)((0, typeguards_1.validateExperimentStatus)(experimentModel, 'devices-instantiated'));
            // await apiClient.unlockBooking(experimentModel.bookingID)
            // await apiClient.deleteBooking(experimentModel.bookingID)
            await deleteInstances(experimentModel);
            break;
        }
        case 'booking-updated': {
            (0, assert_1.default)((0, typeguards_1.validateExperimentStatus)(experimentModel, 'booking-updated'));
            // await apiClient.unlockBooking(experimentModel.bookingID)
            // await apiClient.deleteBooking(experimentModel.bookingID)
            await deleteInstances(experimentModel);
            break;
        }
        case 'peerconnections-created': {
            (0, assert_1.default)((0, typeguards_1.validateExperimentStatus)(experimentModel, 'peerconnections-created'));
            // await apiClient.unlockBooking(experimentModel.bookingID)
            // await apiClient.deleteBooking(experimentModel.bookingID)
            await deletePeerconnections(experimentModel);
            await deleteInstances(experimentModel);
            break;
        }
        case 'running': {
            (0, assert_1.default)((0, typeguards_1.validateExperimentStatus)(experimentModel, 'running'));
            // await apiClient.unlockBooking(experimentModel.bookingID)
            // await apiClient.deleteBooking(experimentModel.bookingID)
            await deletePeerconnections(experimentModel);
            await deleteInstances(experimentModel);
            break;
        }
        case 'finished': {
            break;
        }
    }
    experimentModel.status = 'finished';
    await dataSource_1.repositories.experiment.save(experimentModel);
    service_common_1.logger.log('info', 'Successfully finished experiment', { data: { experimentUrl } });
}
exports.finishExperiment = finishExperiment;
async function deleteInstances(experiment) {
    if (experiment.devices) {
        for (const device of experiment.devices) {
            if (device.instance?.url) {
                await api_1.apiClient.deleteDevice(device.instance.url);
            }
        }
    }
}
async function deletePeerconnections(experiment) {
    if (experiment.connections) {
        for (const peerconnection of experiment.connections) {
            await api_1.apiClient.deletePeerconnection(peerconnection.url);
        }
    }
}
//# sourceMappingURL=finish.js.map