"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.lockBookingExperiment = void 0;
const service_common_1 = require("@crosslab/service-common");
const dataSource_1 = require("../../../database/dataSource");
const errors_1 = require("../../../types/errors");
const typeguards_1 = require("../../../types/typeguards");
const url_1 = require("../../url");
// import { apiClient } from '../../api'
async function lockBookingExperiment(experimentModel) {
    const experimentUrl = (0, url_1.experimentUrlFromId)(experimentModel.uuid);
    service_common_1.logger.log('info', 'Attempting to lock booking for experiment', {
        data: { experimentUrl },
    });
    if (experimentModel.status !== 'booked')
        throw new errors_1.InvalidStateError(`Expected experiment to have status 'booked', instead has status '${experimentModel.status}'`);
    if (!(0, typeguards_1.validateExperimentStatus)(experimentModel, 'booked'))
        throw new errors_1.MalformedExperimentError(`Experiment is in status 'booked', but does not satisfy the requirements for this status`, 500);
    // TODO: error handling
    // await apiClient.lockBooking(experimentModel.bookingID)
    experimentModel.status = 'booking-locked';
    await dataSource_1.repositories.experiment.save(experimentModel);
    service_common_1.logger.log('info', 'Successfully locked booking for experiment', {
        data: { experimentUrl },
    });
}
exports.lockBookingExperiment = lockBookingExperiment;
//# sourceMappingURL=bookingLocking.js.map