"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateBookingExperiment = void 0;
const service_common_1 = require("@crosslab/service-common");
const dataSource_1 = require("../../../database/dataSource");
const errors_1 = require("../../../types/errors");
const typeguards_1 = require("../../../types/typeguards");
const url_1 = require("../../url");
// import { apiClient } from '../../api'
async function updateBookingExperiment(experimentModel, _newDeviceUrls) {
    const experimentUrl = (0, url_1.experimentUrlFromId)(experimentModel.uuid);
    service_common_1.logger.log('info', 'Attempting to update booking for experiment', {
        data: { experimentUrl },
    });
    if (experimentModel.status !== 'devices-instantiated')
        throw new errors_1.InvalidStateError(`Expected experiment to have status 'devices-instantiated', instead has status '${experimentModel.status}'`);
    if (!(0, typeguards_1.validateExperimentStatus)(experimentModel, 'devices-instantiated'))
        throw new errors_1.MalformedExperimentError(`Experiment is in status 'devices-instantiated', but does not satisfy the requirements for this status`, 500);
    // TODO: error handling
    // await apiClient.updateBooking(experimentModel.bookingID, {
    //     Locked: true,
    //     Devices: newDeviceUrls.map((newDeviceUrl) => {
    //         return {
    //             ID: newDeviceUrl,
    //         }
    //     }),
    // })
    experimentModel.status = 'booking-updated';
    await dataSource_1.repositories.experiment.save(experimentModel);
    service_common_1.logger.log('info', 'Successfully updated booking for experiment', {
        data: { experimentUrl },
    });
}
exports.updateBookingExperiment = updateBookingExperiment;
//# sourceMappingURL=bookingUpdate.js.map