"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.instantiateDevicesExperiment = void 0;
const dataSource_1 = require("../../../database/dataSource");
const errors_1 = require("../../../types/errors");
const typeguards_1 = require("../../../types/typeguards");
const api_1 = require("../../api");
const url_1 = require("../../url");
const service_common_1 = require("@crosslab/service-common");
async function instantiateDevicesExperiment(experimentModel, instantiationUrls) {
    const experimentUrl = (0, url_1.experimentUrlFromId)(experimentModel.uuid);
    service_common_1.logger.log('info', 'Attempting to instantiate devices for experiment', {
        data: { experimentUrl },
    });
    if (experimentModel.status !== 'booking-locked')
        throw new errors_1.InvalidStateError(`Expected experiment to have status 'booking-locked', instead has status '${experimentModel.status}'`);
    if (!(0, typeguards_1.validateExperimentStatus)(experimentModel, 'booking-locked'))
        throw new errors_1.MalformedExperimentError(`Experiment is in status 'booking-locked', but does not satisfy the requirements for this status`, 500);
    // TODO: error handling
    const instances = [];
    for (const instantiationUrl of instantiationUrls) {
        const instantiableDevice = experimentModel.devices.find((device) => device.url === instantiationUrl);
        if (!instantiableDevice || instantiableDevice.instance)
            continue;
        const instanceData = await api_1.apiClient.instantiateDevice(instantiationUrl);
        instances.push({ ...instanceData.instance, token: instanceData.deviceToken });
        const instance = await dataSource_1.repositories.instance.create({
            url: instanceData.instance.url,
            token: instanceData.deviceToken,
        });
        await dataSource_1.repositories.instance.save(instance);
        instantiableDevice.instance = instance;
    }
    experimentModel.status = 'devices-instantiated';
    await dataSource_1.repositories.experiment.save(experimentModel);
    service_common_1.logger.log('info', 'Successfully instantiated devices for experiment', {
        data: { experimentUrl },
    });
    return instances;
}
exports.instantiateDevicesExperiment = instantiateDevicesExperiment;
//# sourceMappingURL=deviceInstantiation.js.map