"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupExperiment = void 0;
const bookingLocking_1 = require("./bookingLocking");
const bookingUpdate_1 = require("./bookingUpdate");
const deviceInstantiation_1 = require("./deviceInstantiation");
const peerconnectionCreation_1 = require("./peerconnectionCreation");
const dataSource_1 = require("../../../database/dataSource");
const errors_1 = require("../../../types/errors");
const typeguards_1 = require("../../../types/typeguards");
const service_common_1 = require("@crosslab/service-common");
const url_1 = require("../../url");
async function setupExperiment(experimentModel, resolvedDevices) {
    const experimentUrl = (0, url_1.experimentUrlFromId)(experimentModel.uuid);
    service_common_1.logger.log('info', 'Setting up experiment', { data: { experimentUrl } });
    if (experimentModel.status !== 'booked')
        throw new errors_1.InvalidStateError(`Expected experiment to have status 'booked', instead has status '${experimentModel.status}'`);
    if (!(0, typeguards_1.validateExperimentStatus)(experimentModel, 'booked'))
        throw new errors_1.MalformedExperimentError(`Experiment is in status 'booked', but does not satisfy the requirements for this status`, 500);
    const uninstantiatedDevices = resolvedDevices.filter((device) => (device.type === 'cloud instantiable' ||
        device.type === 'edge instantiable') &&
        (!device.instanceUrl || !device.instanceToken));
    await (0, bookingLocking_1.lockBookingExperiment)(experimentModel);
    if (uninstantiatedDevices) {
        const instances = await (0, deviceInstantiation_1.instantiateDevicesExperiment)(experimentModel, uninstantiatedDevices.map((uninstantiatedDevice) => uninstantiatedDevice.url));
        await (0, bookingUpdate_1.updateBookingExperiment)(experimentModel, instances.map((instance) => instance.url));
    }
    else {
        experimentModel.status = 'booking-updated';
        await dataSource_1.repositories.experiment.save(experimentModel);
    }
    await (0, peerconnectionCreation_1.createPeerconnectionsExperiment)(experimentModel);
    service_common_1.logger.log('info', 'Successfully set up experiment', { data: { experimentUrl } });
}
exports.setupExperiment = setupExperiment;
//# sourceMappingURL=index.js.map