"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createPeerconnectionsExperiment = void 0;
const service_common_1 = require("@crosslab/service-common");
const dataSource_1 = require("../../../database/dataSource");
const errors_1 = require("../../../types/errors");
const typeguards_1 = require("../../../types/typeguards");
const peerconnection_1 = require("../../peerconnection");
const url_1 = require("../../url");
async function createPeerconnectionsExperiment(experimentModel) {
    const experimentUrl = (0, url_1.experimentUrlFromId)(experimentModel.uuid);
    service_common_1.logger.log('info', 'Attempting to create peerconnections for experiment', {
        data: { experimentUrl },
    });
    if (experimentModel.status !== 'booking-updated')
        throw new errors_1.InvalidStateError(`Expected experiment to have status 'booking-updated', instead has status '${experimentModel.status}'`);
    if (!(0, typeguards_1.validateExperimentStatus)(experimentModel, 'booking-updated'))
        throw new errors_1.MalformedExperimentError(`Experiment is in status 'booking-updated', but does not satisfy the requirements for this status`, 500);
    await (0, peerconnection_1.createPeerconnections)(experimentModel);
    experimentModel.status = 'peerconnections-created';
    await dataSource_1.repositories.experiment.save(experimentModel);
    service_common_1.logger.log('info', 'Successfully created peerconnections for experiment', {
        data: { experimentUrl },
    });
}
exports.createPeerconnectionsExperiment = createPeerconnectionsExperiment;
//# sourceMappingURL=peerconnectionCreation.js.map