"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createPeerconnections = void 0;
const dataSource_1 = require("../database/dataSource");
const callbacks_1 = require("../operations/callbacks");
const api_1 = require("./api");
const connectionPlan_1 = require("./connectionPlan");
/**
 * This function attempts to establish the peerconnections for an experiment model according to its connection plan.
 * @param experimentModel The experiment model for which to establish the peerconnections.
 */
async function createPeerconnections(experimentModel) {
    const peerconnectionRequests = (0, connectionPlan_1.buildConnectionPlan)(experimentModel);
    for (const peerconnectionRequest of peerconnectionRequests) {
        // TODO: error handling
        const peerconnection = await api_1.apiClient.createPeerconnection(peerconnectionRequest, {
            closedUrl: callbacks_1.callbackUrl,
            statusChangedUrl: callbacks_1.callbackUrl,
        });
        if (!experimentModel.connections)
            experimentModel.connections = [];
        callbacks_1.peerconnectionClosedCallbacks.push(peerconnection.url);
        callbacks_1.peerconnectionStatusChangedCallbacks.push(peerconnection.url);
        // create, push and save new peerconnection
        const peerconnectionModel = await dataSource_1.repositories.peerconnection.create(peerconnection.url);
        experimentModel.connections.push(peerconnectionModel);
        await dataSource_1.repositories.experiment.save(experimentModel);
    }
}
exports.createPeerconnections = createPeerconnections;
//# sourceMappingURL=peerconnection.js.map