"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleEventCallback = exports.callbackEventEmitter = void 0;
const api_client_1 = require("@cross-lab-project/api-client");
const deviceChanged_1 = require("./deviceChanged");
const peerconnectionClosed_1 = require("./peerconnectionClosed");
const peerconnectionStatusChanged_1 = require("./peerconnectionStatusChanged");
const service_common_1 = require("@crosslab/service-common");
const stream_1 = require("stream");
exports.callbackEventEmitter = new stream_1.EventEmitter();
/**
 * This function handles an incoming event callback.
 * @param callback The incoming event callback to be handled.
 * @throws {MalformedBodyError} Thrown if the callback is malformed.
 * @throws {InvalidValueError} Thrown if the type of the event callback is unknown.
 * @returns The status code of the callback response.
 */
async function handleEventCallback(callback) {
    switch (callback.eventType) {
        case 'peerconnection-status-changed':
            if (!api_client_1.DeviceServiceTypes.isPeerconnectionStatusChangedEventCallback(callback))
                throw new service_common_1.MalformedBodyError('Body of request is not a valid peerconnection-status-changed event callback', 400);
            return await (0, peerconnectionStatusChanged_1.handlePeerconnectionStatusChangedEventCallback)(callback);
        case 'peerconnection-closed':
            if (!api_client_1.DeviceServiceTypes.isPeerconnectionClosedEventCallback(callback))
                throw new service_common_1.MalformedBodyError('Body of request is not a valid peerconnection-closed event callback', 400);
            return (0, peerconnectionClosed_1.handlePeerconnectionClosedEventCallback)(callback);
        case 'device-changed':
            if (!api_client_1.DeviceServiceTypes.isDeviceChangedEventCallback(callback))
                throw new service_common_1.MalformedBodyError('Body of request is not a valid device-changed event callback', 400);
            return (0, deviceChanged_1.handleDeviceChangedEventCallback)(callback);
        default:
            throw new service_common_1.InvalidValueError(`Event-callbacks of type "${callback.eventType}" are not supported`, 400);
    }
}
exports.handleEventCallback = handleEventCallback;
//# sourceMappingURL=index.js.map