"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handlePeerconnectionStatusChangedEventCallback = void 0;
const dataSource_1 = require("../../../database/dataSource");
const api_1 = require("../../../methods/api");
const callbacks_1 = require("../../callbacks");
const service_common_1 = require("@crosslab/service-common");
/**
 * This function handles an incoming "peerconnection-status-changed" event callback.
 * @param callback The incoming "peerconnection-status-changed" callback to be handled.
 * @throws {MissingPropertyError} Thrown if the callback is missing a property.
 * @returns The status code for the response to the incoming callback.
 */
async function handlePeerconnectionStatusChangedEventCallback(callback) {
    if (!callbacks_1.peerconnectionStatusChangedCallbacks.includes(callback.peerconnection.url)) {
        return 410; // TODO: find a solution for this problem (race condition)
    }
    // TODO: add peerconnection status changed handling
    const peerconnectionModel = await dataSource_1.repositories.peerconnection.findOneOrFail({
        where: { url: callback.peerconnection.url },
        relations: {
            experiment: {
                connections: true,
                devices: true,
            },
        },
    });
    const experimentModel = peerconnectionModel.experiment;
    if (!experimentModel)
        throw new service_common_1.MissingPropertyError(`Peerconnection model is missing property "experiment"`); // NOTE: error code
    switch (callback.peerconnection.status) {
        case 'closed':
            // TODO: handle status closed
            break;
        case 'connected': {
            // TODO: handle status connected
            if (!experimentModel.connections)
                throw new service_common_1.MissingPropertyError(`Experiment model is missing property "connections"`, 400); // NOTE: error code
            let connected = true;
            for (const pc of experimentModel.connections) {
                if ((await api_1.apiClient.getPeerconnection(pc.url)).status !== 'connected') {
                    connected = false;
                }
            }
            if (experimentModel.status === 'peerconnections-created' && connected) {
                experimentModel.status = 'running';
                await dataSource_1.repositories.experiment.save(experimentModel);
            }
            break;
        }
        case 'failed':
            // TODO: handle status failed
            break;
        case 'new':
            // TODO: handle status new
            break;
        case 'connecting':
            // TODO: handle status connecting
            break;
        case 'disconnected':
            // TODO: handle status disconnected
            break;
    }
    return 200;
}
exports.handlePeerconnectionStatusChangedEventCallback = handlePeerconnectionStatusChangedEventCallback;
//# sourceMappingURL=peerconnectionStatusChanged.js.map