"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.callbackHandling = exports.deviceChangedCallbacks = exports.peerconnectionStatusChangedCallbacks = exports.peerconnectionClosedCallbacks = exports.callbackUrl = void 0;
const api_client_1 = require("@cross-lab-project/api-client");
const config_1 = require("../../config");
const event_1 = require("./event");
const service_common_1 = require("@crosslab/service-common");
const service_common_2 = require("@crosslab/service-common");
exports.callbackUrl = config_1.config.BASE_URL + (config_1.config.BASE_URL.endsWith('/') ? '' : '/') + `callbacks/experiment`;
exports.peerconnectionClosedCallbacks = [];
exports.peerconnectionStatusChangedCallbacks = [];
exports.deviceChangedCallbacks = new Map();
/**
 * This function adds the endpoint for incoming callbacks registered by the experiment service.
 * @param app The express application the callback endpoint should be added to.
 */
function callbackHandling(app) {
    app.post('/callbacks/experiment', async (req, res, next) => {
        try {
            const callback = req.body;
            service_common_2.logger.log('info', 'received a callback', { data: { callback } });
            if (!api_client_1.DeviceServiceTypes.isCallback(callback))
                throw new service_common_1.MalformedBodyError('Body of request is not a valid callback', 400);
            switch (callback.callbackType) {
                case 'event':
                    if (!api_client_1.DeviceServiceTypes.isEventCallback(callback))
                        throw new service_common_1.MalformedBodyError('Body of request is not a valid event callback', 400);
                    return res.status(await (0, event_1.handleEventCallback)(callback)).send();
                default:
                    throw new service_common_1.InvalidValueError(`Callbacks of type "${callback.callbackType}" are not supported`, 400);
            }
        }
        catch (error) {
            return next(error);
        }
    });
}
exports.callbackHandling = callbackHandling;
//# sourceMappingURL=index.js.map