"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteExperimentsByExperimentId = void 0;
const dataSource_1 = require("../../../database/dataSource");
const experimentStatus_1 = require("../../../methods/experimentStatus");
const service_common_1 = require("@crosslab/service-common");
/**
 * This function implements the functionality for handling DELETE requests on
 * /experiments/{experiment_id} endpoint.
 * @param parameters The parameters of the request.
 * @param _user The user submitting the request.
 */
const deleteExperimentsByExperimentId = async (parameters, _user) => {
    service_common_1.logger.log('info', `Handling DELETE request on endpoint /experiments/${parameters.experiment_id}`);
    const experimentModel = await dataSource_1.repositories.experiment.findOneOrFail({
        where: { uuid: parameters.experiment_id },
        relations: {
            connections: true,
            devices: {
                instance: true,
            },
            roles: true,
            serviceConfigurations: {
                participants: true,
            },
        },
    });
    if (experimentModel.status !== 'finished')
        await (0, experimentStatus_1.finishExperiment)(experimentModel);
    await dataSource_1.repositories.experiment.remove(experimentModel);
    service_common_1.logger.log('info', `Successfully handled DELETE request on endpoint /experiments/${parameters.experiment_id}`);
    return {
        status: 204,
    };
};
exports.deleteExperimentsByExperimentId = deleteExperimentsByExperimentId;
//# sourceMappingURL=delete.js.map