"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchExperimentsByExperimentId = void 0;
const dataSource_1 = require("../../../database/dataSource");
const experimentStatus_1 = require("../../../methods/experimentStatus");
const service_common_1 = require("@crosslab/service-common");
/**
 * This function implements the functionality for handling PATCH requests on
 * /experiment/{experiment_id} endpoint.
 * @param parameters The parameters of the request.
 * @param body The body of the request.
 * @param _user The user submitting the request.
 */
const patchExperimentsByExperimentId = async (parameters, body, _user) => {
    service_common_1.logger.log('info', `Handling PATCH request on endpoint /experiments/${parameters.experiment_id}`);
    const experimentModel = await dataSource_1.repositories.experiment.findOneOrFail({
        where: { uuid: parameters.experiment_id },
        relations: {
            connections: true,
            devices: {
                instance: true,
            },
            roles: true,
            serviceConfigurations: {
                participants: true,
            },
        },
    });
    if (body)
        await dataSource_1.repositories.experiment.write(experimentModel, body);
    if (experimentModel.status === 'booked')
        await (0, experimentStatus_1.bookExperiment)(experimentModel);
    if (experimentModel.status === 'running')
        await (0, experimentStatus_1.runExperiment)(experimentModel);
    if (experimentModel.status === 'finished')
        await (0, experimentStatus_1.finishExperiment)(experimentModel);
    await dataSource_1.repositories.experiment.save(experimentModel);
    service_common_1.logger.log('info', `Successfully handled PATCH request on endpoint /experiments/${parameters.experiment_id}`);
    return {
        status: 200,
        body: await dataSource_1.repositories.experiment.format(experimentModel),
    };
};
exports.patchExperimentsByExperimentId = patchExperimentsByExperimentId;
//# sourceMappingURL=patch.js.map