"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postExperiments = void 0;
const dataSource_1 = require("../../database/dataSource");
const experimentStatus_1 = require("../../methods/experimentStatus");
const service_common_1 = require("@crosslab/service-common");
/**
 * This function implements the functionality for handling POST requests on
 * /experiments endpoint.
 * @param body The body of the request.
 * @param _user The user submitting the request.
 */
const postExperiments = async (body, _user) => {
    service_common_1.logger.log('info', 'Handling POST request on endpoint /experiments');
    const experimentModel = await dataSource_1.repositories.experiment.create(body);
    const requestedStatus = body.status;
    await dataSource_1.repositories.experiment.save(experimentModel);
    if (requestedStatus === 'booked')
        await (0, experimentStatus_1.bookExperiment)(experimentModel);
    if (requestedStatus === 'running')
        await (0, experimentStatus_1.runExperiment)(experimentModel);
    if (requestedStatus === 'finished')
        await (0, experimentStatus_1.finishExperiment)(experimentModel);
    await dataSource_1.repositories.experiment.save(experimentModel); // NOTE: truly needed?
    service_common_1.logger.log('info', 'Successfully handled POST request on endpoint /experiments');
    return {
        status: 201,
        body: await dataSource_1.repositories.experiment.format(experimentModel),
    };
};
exports.postExperiments = postExperiments;
//# sourceMappingURL=post.js.map