"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MalformedExperimentError = exports.InvalidBookingError = exports.InternalRequestError = exports.InvalidStateError = exports.ServiceConfigurationError = void 0;
const types_1 = require("../generated/types");
/**
 * This error class should be used if a service configuration is faulty.
 */
class ServiceConfigurationError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'ServiceConfigurationError';
    }
}
exports.ServiceConfigurationError = ServiceConfigurationError;
/**
 * This error class should be used if an operation cannot be executed from the current state.
 */
class InvalidStateError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InvalidStateError';
    }
}
exports.InvalidStateError = InvalidStateError;
/**
 * This error class should be used as a wrapper for errors thrown by the api-client.
 */
class InternalRequestError extends types_1.ErrorWithStatus {
    constructor(message, error, status) {
        super(message, status);
        this.name = 'InternalRequestError';
        this.internalError = error;
    }
}
exports.InternalRequestError = InternalRequestError;
/**
 * This error class should be used if a booking is invalid.
 */
class InvalidBookingError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InvalidBookingError';
    }
}
exports.InvalidBookingError = InvalidBookingError;
/**
 * This error class should be used if an experiment does not meet the
 * requirements of its current status.
 */
class MalformedExperimentError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'MalformedExperimentError';
    }
}
exports.MalformedExperimentError = MalformedExperimentError;
//# sourceMappingURL=errors.js.map